==> kde-l10n-lt-4.5.5-noarch-1.tgz: install/doinst.sh <==
( cd usr/share/doc/HTML/lt/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/lt/kwrite ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/lt/kdepasswd ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/lt/kgpg ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcontrol/khtml-plugins ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcontrol/khtml-plugins ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmenuedit ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kioslave/cgi ; rm -rf common )
( cd usr/share/doc/HTML/lt/kioslave/cgi ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/lt/ksnapshot ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/klipper ; rm -rf common )
( cd usr/share/doc/HTML/lt/klipper ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcalc ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmix ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmix ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kdiamond ; rm -rf common )
( cd usr/share/doc/HTML/lt/kdiamond ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmahjongg ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/dolphin ; rm -rf common )
( cd usr/share/doc/HTML/lt/dolphin ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kfind ; rm -rf common )
( cd usr/share/doc/HTML/lt/kfind ; ln -sf /usr/share/doc/HTML/lt//common common )

==> kde-l10n-lt-4.8.5-noarch-1.tgz: install/doinst.sh <==
( cd usr/share/doc/HTML/lt/klipper ; rm -rf common )
( cd usr/share/doc/HTML/lt/klipper ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/lt/kdepasswd ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kfind ; rm -rf common )
( cd usr/share/doc/HTML/lt/kfind ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/akregator ; rm -rf common )
( cd usr/share/doc/HTML/lt/akregator ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmix ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmix ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/lt/ksnapshot ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/marble ; rm -rf common )
( cd usr/share/doc/HTML/lt/marble ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/lt/kwrite ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kioslave/cgi ; rm -rf common )
( cd usr/share/doc/HTML/lt/kioslave/cgi ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmenuedit ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kdiamond ; rm -rf common )
( cd usr/share/doc/HTML/lt/kdiamond ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcalc ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kcontrol/khtml-plugins ; rm -rf common )
( cd usr/share/doc/HTML/lt/kcontrol/khtml-plugins ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/dolphin ; rm -rf common )
( cd usr/share/doc/HTML/lt/dolphin ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/lt/kmahjongg ; ln -sf /usr/share/doc/HTML/lt//common common )
( cd usr/share/doc/HTML/lt/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/lt/kgpg ; ln -sf /usr/share/doc/HTML/lt//common common )
